==> centreon-web-24.10.16.tar.gz: centreon-web-24.10.16/packages/js-config/rspack/base/globalConfig.js <==
const isDev = process.env.NODE_ENV !== 'production';

const excludeNodeModulesExceptCentreonUi =
  /node_modules(\\|\/)\.pnpm(\\|\/)(?!(@centreon|file\+packages\+ui-context))/;

module.exports = {
  cache: false,
  excludeNodeModulesExceptCentreonUi,
  getModuleConfiguration: (enableCoverage) => ({
    rules: [
      {
        exclude: [excludeNodeModulesExceptCentreonUi],
        test: /\.[jt]sx?$/,
        use: {
          loader: 'swc-loader',
          options: {
            jsc: {
              experimental: {
                plugins: [
                  enableCoverage && ['swc-plugin-coverage-instrument', {}]
                ].filter(Boolean)
              },
              parser: {
                syntax: 'typescript',
                tsx: true
              },
              transform: {
                react: {
                  development: isDev,
                  refresh: isDev
                }
              }
            }
          }
        }
      },
      {
        test: /\.icon.svg$/,
        use: ['@svgr/webpack']
      },
      {
        exclude: excludeNodeModulesExceptCentreonUi,
        test: /\.(bmp|png|jpg|jpeg|gif|svg)$/,
        type: 'asset/inline'
      },
      {
        generator: {
          filename: '[name][ext]'
        },
        test: /\.(woff|woff2|eot|ttf|otf)$/i,
        type: 'asset/resource'
      },
      {
        test: /\.css$/i,
        use: ['style-loader', 'css-loader']
      }
    ]
  }),
  optimization: {
    splitChunks: {
      chunks: 'all',
      maxSize: 400 * 1024
    }
  },
  output: {
    chunkFilename: isDev
      ? '[name].[chunkhash:8].chunk.js'
      : '[name].[contenthash].[chunkhash].[hash].js',
    filename: isDev
      ? '[name].[chunkhash:8].js'
      : '[name].[contenthash].[hash].js',
    libraryTarget: 'umd',
    umdNamedDefine: true
  }
};

==> centreon-web-24.11.0.tar.gz: centreon-web-24.11.0/packages/js-config/rspack/base/globalConfig.js <==
const isDev = process.env.NODE_ENV !== 'production';

const excludeNodeModulesExceptCentreonUi =
  /node_modules(\\|\/)\.pnpm(\\|\/)(?!(@centreon|file\+packages\+ui-context))/;

module.exports = {
  cache: false,
  excludeNodeModulesExceptCentreonUi,
  getModuleConfiguration: (enableCoverage) => ({
    rules: [
      {
        exclude: [excludeNodeModulesExceptCentreonUi],
        test: /\.[jt]sx?$/,
        use: {
          loader: 'swc-loader',
          options: {
            jsc: {
              experimental: {
                plugins: [
                  enableCoverage && ['swc-plugin-coverage-instrument', {}]
                ].filter(Boolean)
              },
              parser: {
                syntax: 'typescript',
                tsx: true
              },
              transform: {
                react: {
                  development: isDev,
                  refresh: isDev
                }
              }
            }
          }
        }
      },
      {
        test: /\.icon.svg$/,
        use: ['@svgr/webpack']
      },
      {
        exclude: excludeNodeModulesExceptCentreonUi,
        test: /\.(bmp|png|jpg|jpeg|gif|svg)$/,
        type: 'asset/inline'
      },
      {
        generator: {
          filename: '[name][ext]'
        },
        test: /\.(woff|woff2|eot|ttf|otf)$/i,
        type: 'asset/resource'
      },
      {
        test: /\.css$/i,
        use: ['style-loader', 'css-loader']
      }
    ]
  }),
  optimization: {
    splitChunks: {
      chunks: 'all',
      maxSize: 400 * 1024
    }
  },
  output: {
    chunkFilename: '[name].[chunkhash:8].chunk.js',
    filename: '[name].[chunkhash:8].js',
    libraryTarget: 'umd',
    umdNamedDefine: true
  }
};
